@@ -27,7 +27,7 @@ import warnings
 from pkgutil import find_loader
 from collections import OrderedDict
 from copy import copy, deepcopy
-from typing import Union  # noqa F401
+from typing import Union, Optional  # noqa F401
 
 import numpy as np
 from osgeo import gdal, gdal_array, gdalnumeric
@@ -379,7 +379,14 @@ class GeoArray(object):
 
     @nodata.setter
     def nodata(self, value):
-        # type: (Union[int, None]) -> None
+        # type: (Optional[bool, int, float]) -> None
+        if isinstance(value, np.bool_):
+            value = bool(value)
+        elif isinstance(value, np.integer):
+            value = int(value)
+        elif isinstance(value, np.floating):
+            value = float(value)
+
         self._nodata = value
 
         if self._metadata and value is not None:
@@ -1150,6 +1157,8 @@ class GeoArray(object):
         out_nodata = in_nodata if in_nodata is not None else -9999
         if not np.can_cast(out_nodata, image2plot.dtype):
             image2plot = image2plot.astype(np.int32)
+        if image2plot.dtype == bool:
+            image2plot = image2plot.astype(int)
 
         # rotated images always have to be resampled for plotting
         if not ignore_rotation and (gt[2] or gt[4]):
@@ -1732,10 +1741,10 @@ class GeoArray(object):
 
         # apply zslice to bandnames and metadata
         if zslicing:
-            bNs_out = list(np.array(list(self.bandnames))[zslice])
+            bNs_out = list(np.array(list(self._bandnames))[zslice]) if self._bandnames else None
             _meta_out = self.metadata.get_subset(bands2extract=zslice)
         else:
-            bNs_out = list(self.bandnames)
+            bNs_out = list(self._bandnames) if self._bandnames else None
             _meta_out = self.meta
 
         sub_gA.gt = sub_gt
